@@ -550,7 +550,7 @@ class h5sol_HPLC(h5xs):
         
     def bin_subtracted_frames(self, sn=None, frame_range=None, first_frame=0, last_frame=-1, weighted=True,
                               plot_data=True, fig=None, qmax=0.5, qs=0.01,
-                              save_data=False, path="", debug=False): 
+                              save_data=False, path="", debug=False, txtWidget=None): 
         """ this is typically used after running subtract_buffer_SVD()
             the frames are specified by either first_frame and last_frame, or frame_range, e.g. "50-60"
             if path is used, be sure that it ends with '/'
@@ -584,7 +584,8 @@ class h5sol_HPLC(h5xs):
                 ax1.errorbar(d1s0.qgrid, d1s0.data, d1s0.err)
                 ax1.set_xlim(0,qmax)
                 i0,rg,_ = d1s0.plot_Guinier(qs=qs, ax=ax2)
-            #print(f"I0={i0:.2g}, Rg={rg:.2f}")
+                if txtWidget is not None:
+                    txtWidget.value = f"I0={i0:.3g}, Rg={rg:.2f}"
 
         if plot_data:
             plt.tight_layout()   
@@ -710,10 +711,15 @@ class h5sol_HT(h5xs):
                 filter_data=True, debug=False, N = 1):
         """ does everything: load data from 2D images, merge, then subtract buffer scattering
         """
+        if filter_data=="keep":
+            self.load_d1s()
         self.load_data(update_only=update_only, detectors=detectors, reft=reft, 
                        save_1d=save_1d, save_merged=save_merged, debug=debug, N=N)
         self.set_trans(transMode=trans_mode.from_waxs)
-        self.average_samples(update_only=update_only, filter_data=filter_data, debug=debug)
+        if filter_data=="keep":
+            self.average_samples(update_only=update_only, filter_data=False, selection=None, debug=debug)
+        else:
+            self.average_samples(update_only=update_only, filter_data=filter_data, debug=debug)
         self.subtract_buffer(update_only=update_only, sc_factor=sc_factor, debug=debug)
         
     def average_samples(self, **kwargs):
@@ -744,12 +750,12 @@ class h5sol_HT(h5xs):
             else:
                 self.d1b[sn] = self.d1s[bns[0]]['averaged'].avg([self.d1s[bn]['averaged'] for bn in bns[1:]], 
                                                                 debug=debug)
-            if sc_factor is "auto":
+            if sc_factor=="auto":
                 sf = estimate_scaling_factor(self.d1s[sn]['averaged'], self.d1b[sn])
                 # Data1d.bkg_cor() normalizes trans first before applying sc_factor
                 # in contrast the estimated 
                 sf /= self.d1s[sn]['averaged'].trans/self.d1b[sn].trans
-                if debug is not "quiet":
+                if debug!="quiet":
                     print(f"setting sc_factor for {sn} to {sf:.4f}")
                 self.attrs[sn]['sc_factor'] = sf
             elif sc_factor>0:
